<?xml version="1.0"?>
<!DOCTYPE xsl:stylesheet [<!ENTITY nbsp "&#160;">]>

<xsl:stylesheet version='1.0' xmlns:xsl='http://www.w3.org/1999/XSL/Transform'>
  <xsl:output method="html" version="4" encoding="UTF-8"/>

   <!--
   *******************************************************************************
   * Output HTML fields to keep the current context
   * @param searchresult The current search result tree
   * @param expandedgroups A tree representing the groups that have been expanded
   *******************************************************************************
   -->
   <xsl:template name="contextKeeper">
      <xsl:param name="pagedSearch"/>
	  <input type="hidden" name="stopsearch" value=""/>
	  <input type="hidden" name="expandgroup" value=""/>
	  <input type="hidden" name="expandselectedgroup" value=""/>
	  <input type="hidden" name="expandonmissing" value=""/>
	  <input type="hidden" name="nextview" value="{/xslui/@nextview}" />
	  <input type="hidden" name="bookid">
	  <xsl:attribute name="value">
	    <xsl:if test="$pagedSearch and $pagedSearch/searchresult and $pagedSearch/searchresult/@bookid">
	      <xsl:value-of select="$pagedSearch/searchresult/@bookid"/>
	    </xsl:if>
	  </xsl:attribute>
	  </input>
	  <input type="hidden" name="actionbookid">
	  <xsl:attribute name="value">
	   <xsl:if test="$pagedSearch and $pagedSearch/searchresult and $pagedSearch/searchresult/@bookid">
	     <xsl:value-of select="$pagedSearch/searchresult/@bookid"/>
	   </xsl:if>
	  </xsl:attribute>
	  </input>
	  <xsl:if test="$pagedSearch/searchresult">
	     <xsl:variable name="searchResult" select="$pagedSearch/searchresult"/>
   	     <xsl:if test="/xslui/iab/pagedsearch/searchresult/@searchid">
           <input type="hidden" name="searchid" value="{$searchResult/@searchid}"/>
	     </xsl:if>
         <input type="hidden" name="filter" value="{$searchResult/@filter}"/>
         <input type="hidden" name="firstentry" value="{$searchResult/@firstentry}"/>
         <input type="hidden" name="sortby" value="{$searchResult/@sortby}"/>
   	     <xsl:if test="$pagedSearch/expandedgroups">
	     <xsl:variable name="expandedGroups" select="$pagedSearch/expandedgroups"/>
	         <xsl:if test="$expandedGroups/expandedgroup">
	             <xsl:for-each select="$expandedGroups/expandedgroup">
	               <input type="hidden" name="expandedgroup" value="{@entryID}"/>
	             </xsl:for-each>
	         </xsl:if>
        </xsl:if>
    </xsl:if>
  </xsl:template>

  <!--
  *******************************************************************************
  * This template prints the error message in the info banner (search page)
  * Only generic messages are printed by this template. Messages
  *   specific to a particular page, are displayed by a template called
  *   error-message which is specific to the page.
  *   
  *******************************************************************************
  -->
  <xsl:template match="error" mode="plain">
  <xsl:param name="type" select="'error'"/>

  <table border="0" cellpadding="0" cellspacing="0" title="">
    <tr>
      <td valign="top" colspan="3"><img src="../absimx/spacer.gif" width="1" height="10"/></td>
    </tr>
    <tr>
      <td valign="top"><img src="../absimx/spacer.gif" width="10" height="1"/></td>
      <xsl:choose>
      <xsl:when test="$type='error'">
       <td valign="top"><img src="../absimx/Error_Large.gif" width="21" height="22" alt="Error" vspace="3" />&#160;&#160;</td>
       <td><span class="AlrtErrTxt"><xsl:call-template name="error-message"/></span></td>
     </xsl:when>
     <xsl:when test="$type='warning'">
       <td valign="top"><img src="../absimx/Warning_Large.gif" width="21" height="22" alt="Warning" vspace="3" />&#160;&#160;</td>
       <td><span class="AlrtWrnTxt"><xsl:call-template name="error-message"/></span></td>
     </xsl:when>
     <xsl:when test="$type='information'">
       <td valign="top"><img src="../absimx/Info_Large.gif" width="21" height="22" alt="Information" vspace="3" />&#160;&#160;</td>
       <td><span class="AlrtInfTxt"><xsl:call-template name="error-message"/></span></td>
     </xsl:when>
     </xsl:choose>
    </tr>
  </table>
  </xsl:template>

  <xsl:template name="uwcbutton">
    <xsl:param name="class" />
    <xsl:param name="title"/> 
    <xsl:param name="tabindex" select="1"/> 
    <xsl:param name="type" select="button"/> 
    <xsl:param name="id" />
    <xsl:param name="name" />
    <xsl:param name="value" />
    <xsl:param name="onclick" />
    <input>
     <xsl:attribute name="name">
      <xsl:value-of select="$name" /> 
     </xsl:attribute>
     <xsl:attribute name="class">
      <xsl:value-of select="$class" /> 
     </xsl:attribute>
     <xsl:attribute name="title">
      <xsl:value-of select="$title" /> 
     </xsl:attribute>
     <xsl:attribute name="type">
      <xsl:value-of select="$type" /> 
     </xsl:attribute>
     <xsl:attribute name="id">
      <xsl:value-of select="$id" /> 
     </xsl:attribute>
     <xsl:attribute name="tabindex">
      <xsl:value-of select="$tabindex" /> 
     </xsl:attribute>
     <xsl:attribute name="onclick">
      <xsl:value-of select="$onclick" /> 
     </xsl:attribute>
     <xsl:attribute name="value">
      <xsl:value-of select="$value" /> 
     </xsl:attribute>
     <xsl:attribute name="onblur">
       <xsl:text>if (this.disabled==0) this.className='</xsl:text><xsl:value-of select="$class" /><xsl:text>'</xsl:text>
     </xsl:attribute>
     <xsl:attribute name="onmouseOver">
       <xsl:text>if (this.disabled==0) this.className='</xsl:text><xsl:value-of select="$class" /><xsl:text>Hov'</xsl:text>
     </xsl:attribute>
    <xsl:attribute name="onFocus">
       <xsl:text>if (this.disabled==0) this.className='</xsl:text><xsl:value-of select="$class" /><xsl:text>Hov'</xsl:text>
     </xsl:attribute>
     <xsl:attribute name="onmouseOut">
       <xsl:text>if (this.disabled==0) this.className='</xsl:text><xsl:value-of select="$class" /><xsl:text>'</xsl:text>
     </xsl:attribute>
    </input>  
 </xsl:template>
 
  <!--
  *******************************************************************************
  * This template prints the action buttons Save, Cancel and Help
  * For each button is called the javascript function of the same name : 
  *   save(), cancel(), help()
  * The core of those functions must be declared in the main template
  *******************************************************************************
  -->
  <xsl:template name="save-cancel-help-bar">
    <xsl:param name="actionframe"/>
    <table border="0" cellspacing="0" cellpadding="0" width="100&#37;" summary="This table displays the save,  canceland help buttons">
      <tbody>
      <tr> 
      <td align="right">           
	    <input class="Btn1" type="submit" name="Button5" id="button" onMouseOver="if (this.disabled==0) this.className='Btn1Hov'" onFocus="if (this.disabled==0) this.className='Btn1Hov'" onMouseOut="if (this.disabled==0) this.className='Btn1'" onBlur="if (this.disabled==0) this.className='Btn1'" tabindex="2">
          <xsl:attribute name="value">
             <xsl:text>_Save</xsl:text>
          </xsl:attribute>
          <xsl:attribute name="title">
             <xsl:text>_Save</xsl:text>
          </xsl:attribute>
          <xsl:attribute name="onClick">
	        <xsl:text>javascript:</xsl:text>
	        <xsl:if test="string-length($actionframe) &gt; 0">
	          <xsl:text>top.</xsl:text><xsl:value-of select="$actionframe"/><xsl:text>.</xsl:text>
	        </xsl:if>
	        <xsl:text>save()</xsl:text>
	      </xsl:attribute>
	    </input>
        &nbsp;
        <input class="Btn2" type="submit" name="Button5" id="button" onMouseOver="if (this.disabled==0) this.className='Btn2Hov'" onFocus="if (this.disabled==0) this.className='Btn2Hov'" onMouseOut="if (this.disabled==0) this.className='Btn2'" onBlur="if (this.disabled==0) this.className='Btn2'" tabindex="3">
          <xsl:attribute name="value">
             <xsl:text>_Cancel</xsl:text>
          </xsl:attribute>
          <xsl:attribute name="title">
             <xsl:text>_Cancel</xsl:text>
          </xsl:attribute>
          <xsl:attribute name="onClick">
	        <xsl:text>javascript:</xsl:text>
	        <xsl:if test="string-length($actionframe) &gt; 0">
	          <xsl:text>top.</xsl:text><xsl:value-of select="$actionframe"/><xsl:text>.</xsl:text>
	        </xsl:if>
	        <xsl:text>cancel()</xsl:text>
	      </xsl:attribute>
	    </input>
        &nbsp;
        <input class="Btn2" type="submit" name="Button52" id="button" onMouseOver="if (this.disabled==0) this.className='Btn2Hov'" onFocus="if (this.disabled==0) this.className='Btn2Hov'" onMouseOut="if (this.disabled==0) this.className='Btn2'" onBlur="if (this.disabled==0) this.className='Btn2'" tabindex="4">                  
         <xsl:attribute name="value">
             <xsl:text>_Help</xsl:text>
          </xsl:attribute>
          <xsl:attribute name="title">
             <xsl:text>_Help</xsl:text>
          </xsl:attribute>
      <xsl:attribute name="onClick">
                <xsl:text>javascript:</xsl:text>
                <xsl:if test="string-length($actionframe) &gt; 0">
                  <xsl:text>top.</xsl:text><xsl:value-of select="$actionframe"/><xsl:text>.</xsl:text>
                </xsl:if>
                <xsl:text>help()</xsl:text>
              </xsl:attribute>
            </input>
      </td>      
     </tr>
     <tr>
       <td colspan="3"><img alt="" src="{$spacer.gif}" width="1" height="6"/></td>
     </tr>
     </tbody>
    </table>    
  </xsl:template> 


<xsl:template name="edit-delete-cancel-help-bar">
    <xsl:param name="helpurl" select="'javascript:urlNotYetAvailable()'" />
    <xsl:param name="actionframe"/>
    <xsl:param name="group"/>
    <td>
       <input class="Btn2" id="delete" onblur="if (this.disabled==0) this.className='Btn2'" onmouseover="if (this.disabled==0) this.className='Btn2Hov'" onfocus="if (this.disabled==0) this.className='Btn2Hov'" tabIndex="5" onmouseout="if (this.disabled==0) this.className='Btn2'" type="button" name="delete">
        <xsl:attribute name="value">
             <xsl:text>_Delete</xsl:text>
          </xsl:attribute>
          <xsl:attribute name="title">
             <xsl:text>_Delete</xsl:text>
          </xsl:attribute>
       <xsl:attribute name="onClick">
            <xsl:text>javascript:</xsl:text>
               <xsl:if test="string-length($actionframe) &gt; 0">
                   <xsl:text>top.</xsl:text><xsl:value-of select="$actionframe"/><xsl:text>.</xsl:text>
               </xsl:if>
               <xsl:text>deleteSelectedGroup()</xsl:text>
          </xsl:attribute>
        </input>
        &nbsp;
       <input class="Btn2" id="edit" onBlur="if (this.disabled==0) this.className='Btn2'" onMouseOver="if (this.disabled==0) this.className='Btn2Hov'" onFocus="if (this.disabled==0) this.className='Btn2Hov'" tabindex="4" onMouseOut="if (this.disabled==0) this.className='Btn2'" type="button" name="edit">
        <xsl:attribute name="value">
             <xsl:text>_Edit</xsl:text>
          </xsl:attribute>
          <xsl:attribute name="title">
             <xsl:text>_Edit</xsl:text>
          </xsl:attribute>
       <xsl:attribute name="onClick">
            <xsl:text>javascript:</xsl:text>
            <xsl:if test="string-length($actionframe) &gt; 0">
              <xsl:text>top.</xsl:text><xsl:value-of select="$actionframe"/><xsl:text>.</xsl:text>
            </xsl:if>
            <xsl:text>editSelectedGroup()</xsl:text>
        </xsl:attribute>
       </input>
       </td>
      <td align="right"> 
      <input class="Btn1" id="save" onblur="if (this.disabled==0) this.className='Btn1'" onmouseover="if (this.disabled==0) this.className='Btn1Hov'" onfocus="if (this.disabled==0) this.className='Btn1Hov'" tabIndex="1" onmouseout="if (this.disabled==0) this.className='Btn1'" type="button" name="close">
         <xsl:attribute name="value">
             <xsl:text>_Close</xsl:text>
          </xsl:attribute>
          <xsl:attribute name="title">
             <xsl:text>_Close</xsl:text>
          </xsl:attribute>
         <xsl:attribute name="onClick">
            <xsl:text>javascript:</xsl:text>
            <xsl:if test="string-length($actionframe) &gt; 0">
              <xsl:text>top.</xsl:text><xsl:value-of select="$actionframe"/><xsl:text>.</xsl:text>
            </xsl:if>
            <xsl:text>cancel()</xsl:text>
         </xsl:attribute>
       </input>&nbsp;
       <input class="Btn2" id="help" onblur="if (this.disabled==0) this.className='Btn2'" onmouseover="if (this.disabled==0) this.className='Btn2Hov'" onfocus="if (this.disabled==0) this.className='Btn2Hov'"  tabIndex="3" onmouseout="if (this.disabled==0) this.className='Btn2'" type="button" name="help"> 
          <xsl:attribute name="value">
             <xsl:text>_Help</xsl:text>
          </xsl:attribute>
          <xsl:attribute name="title">
             <xsl:text>_Help</xsl:text>
          </xsl:attribute>
        <xsl:attribute name="onClick">
         <xsl:text>javascript:</xsl:text>
            <xsl:if test="string-length($actionframe) &gt; 0">
              <xsl:text>top.</xsl:text><xsl:value-of select="$actionframe"/><xsl:text>.</xsl:text>
            </xsl:if>
            <xsl:text>openHelp()</xsl:text>
         </xsl:attribute>
         </input>
          </td>
</xsl:template>


  <!--
  *******************************************************************************
  * This template prints the action buttons Save, 'Save and Add Another', Cancel and Help
  * For each button is called the javascript function of the same name : 
  *   save(), saveAndAddAnother(), cancel(), help()
  * The core of those functions must be declared in the main template
  *******************************************************************************
  -->
  <xsl:template name="save-saveandaddanother-cancel-help-bar">
    <xsl:param name="actionframe"/>
    <table border="0" cellspacing="0" cellpadding="0" width="100&#37;" summary="This table displays the save, save-and-add-another,  cancel and help buttons">
      <tbody>
      <tr> 
      <td align="right">           
	    <input class="Btn1" type="submit" name="Button5" id="button" onMouseOver="if (this.disabled==0) this.className='Btn1Hov'" onFocus="if (this.disabled==0) this.className='Btn1Hov'" onMouseOut="if (this.disabled==0) this.className='Btn1'" onBlur="if (this.disabled==0) this.className='Btn1'" tabindex="2">
          <xsl:attribute name="value">
             <xsl:text>_Save</xsl:text>
          </xsl:attribute>
          <xsl:attribute name="title">
             <xsl:text>_Save</xsl:text>
          </xsl:attribute>
          <xsl:attribute name="onClick">
	        <xsl:text>javascript:</xsl:text>
	        <xsl:if test="string-length($actionframe) &gt; 0">
	          <xsl:text>top.</xsl:text><xsl:value-of select="$actionframe"/><xsl:text>.</xsl:text>
	        </xsl:if>
	        <xsl:text>save()</xsl:text>
	      </xsl:attribute>
	    </input>
        &nbsp;
	    <input class="Btn1" type="submit" name="Button5" id="button" onMouseOver="if (this.disabled==0) this.className='Btn1Hov'" onFocus="if (this.disabled==0) this.className='Btn1Hov'" onMouseOut="if (this.disabled==0) this.className='Btn1'" onBlur="if (this.disabled==0) this.className='Btn1'" tabindex="3">
            <xsl:attribute name="value">
             <xsl:text>_Save and Add Another</xsl:text>
          </xsl:attribute>
          <xsl:attribute name="title">
             <xsl:text>_Save and Add Another</xsl:text>
          </xsl:attribute>
          <xsl:attribute name="onClick">
	        <xsl:text>javascript:</xsl:text>
	        <xsl:if test="string-length($actionframe) &gt; 0">
	          <xsl:text>top.</xsl:text><xsl:value-of select="$actionframe"/><xsl:text>.</xsl:text>
	        </xsl:if>
	        <xsl:text>save(true)</xsl:text>
	      </xsl:attribute>
	    </input>
        &nbsp;
        <input class="Btn2" type="submit" name="Button51" id="button" onMouseOver="if (this.disabled==0) this.className='Btn2Hov'" onFocus="if (this.disabled==0) this.className='Btn2Hov'" onMouseOut="if (this.disabled==0) this.className='Btn2'" onBlur="if (this.disabled==0) this.className='Btn2'" tabindex="4">
            <xsl:attribute name="value">
             <xsl:text>_Cancel</xsl:text>
          </xsl:attribute>
          <xsl:attribute name="title">
             <xsl:text>_Cancel</xsl:text>
          </xsl:attribute>
          <xsl:attribute name="onClick">
	        <xsl:text>javascript:</xsl:text>
	        <xsl:if test="string-length($actionframe) &gt; 0">
	          <xsl:text>top.</xsl:text><xsl:value-of select="$actionframe"/><xsl:text>.</xsl:text>
	        </xsl:if>
	        <xsl:text>cancel()</xsl:text>
	      </xsl:attribute>
	    </input>
        &nbsp;
        <input class="Btn2" type="submit" name="Button52" id="button" onMouseOver="if (this.disabled==0) this.className='Btn2Hov'" onFocus="if (this.disabled==0) this.className='Btn2Hov'" onMouseOut="if (this.disabled==0) this.className='Btn2'" onBlur="if (this.disabled==0) this.className='Btn2'" onClick="" tabindex="5">                  
         <xsl:attribute name="value">
             <xsl:text>_Help</xsl:text>
          </xsl:attribute>
          <xsl:attribute name="title">
             <xsl:text>_Help</xsl:text>
          </xsl:attribute>
      <xsl:attribute name="onClick">
                <xsl:text>javascript:</xsl:text>
                <xsl:if test="string-length($actionframe) &gt; 0">
                  <xsl:text>top.</xsl:text><xsl:value-of select="$actionframe"/><xsl:text>.</xsl:text>
                </xsl:if>
                <xsl:text>help()</xsl:text>
              </xsl:attribute>
            </input>
      </td>      
     </tr>
     <tr>
       <td colspan="3"><img alt="" src="{$spacer.gif}" width="1" height="6"/></td>
     </tr>
     </tbody>
    </table>    
  </xsl:template> 

  <!--
  *******************************************************************************
  * This template prints the action buttons Ok, Cancel and Help
  * For each button is called the javascript function of the same name : 
  *   ok(), cancel(), help()
  * The core of those functions must be declared in the main template
  *******************************************************************************
  -->
  <xsl:template name="ok-cancel-help-bar">
    <xsl:param name="buttontext" select="'OK'" />
    <xsl:param name="buttoncontext" select="'_OK'" />
    <xsl:param name="language" select="'en'"/>
    <xsl:param name="actionframe"/>
    <table border="0" cellspacing="0" cellpadding="0" width="100&#37;" summary="This table displays the ok, cancel and help buttons">
      <tbody>
      <tr> 
      <td align="right">           
	    <input class="Btn1" type="submit" name="Button" id="button" onmouseover="if (this.disabled==0) this.className='Btn1Hov'" onfocus="if (this.disabled==0) this.className='Btn1Hov'" onmouseout="if (this.disabled==0) this.className='Btn1'" onblur="if (this.disabled==0) this.className='Btn1'" tabindex="1">
	      <xsl:attribute name="value"><xsl:value-of select="$buttontext"/></xsl:attribute>
	      <xsl:attribute name="title"><xsl:value-of select="$buttontext"/></xsl:attribute>
	      <xsl:attribute name="onClick">
	        <xsl:text>javascript:</xsl:text>
	        <xsl:if test="string-length($actionframe) &gt; 0">
	          <xsl:text>top.</xsl:text><xsl:value-of select="$actionframe"/>
	          <xsl:text>.</xsl:text>
	        </xsl:if>
	        <xsl:text>ok()</xsl:text>
	      </xsl:attribute>
	    </input>
        &nbsp;
        <input class="Btn2" type="submit" name="Button5" id="button" onMouseOver="if (this.disabled==0) this.className='Btn2Hov'" onFocus="if (this.disabled==0) this.className='Btn2Hov'" onMouseOut="if (this.disabled==0) this.className='Btn2'" onBlur="if (this.disabled==0) this.className='Btn2'" tabindex="3">
         <xsl:attribute name="value">
          <xsl:text>_Cancel</xsl:text> 
         </xsl:attribute>
         <xsl:attribute name="title">
           <xsl:text>_Cancel</xsl:text> 
         </xsl:attribute>
          <xsl:attribute name="onClick">
	        <xsl:text>javascript:</xsl:text>
	        <xsl:if test="string-length($actionframe) &gt; 0">
	          <xsl:text>top.</xsl:text><xsl:value-of select="$actionframe"/><xsl:text>.</xsl:text>
	        </xsl:if>
	        <xsl:text>cancel()</xsl:text>
	      </xsl:attribute>
	    </input>
        &nbsp;
        <input class="Btn2" type="submit" name="Button52" id="button" onMouseOver="if (this.disabled==0) this.className='Btn2Hov'" onFocus="if (this.disabled==0) this.className='Btn2Hov'" onMouseOut="if (this.disabled==0) this.className='Btn2'" onBlur="if (this.disabled==0) this.className='Btn2'" onClick="" tabindex="4">                  
         <xsl:attribute name="value">
          <xsl:text>_Help</xsl:text>
         </xsl:attribute>
         <xsl:attribute name="title">
           <xsl:text>_Help</xsl:text> 
         </xsl:attribute> 
         <xsl:attribute name="onClick">
           <xsl:text>javascript:openhelp('</xsl:text>
           <xsl:choose>
           <xsl:when test="$buttoncontext='AddInvitees'">
             <xsl:value-of select="/xslui/@contexturi"/>
             <xsl:text>/help/</xsl:text><xsl:value-of select="$language"/><xsl:text>/addressbk/nesrchadd.html#wp26952');</xsl:text>
           </xsl:when>
          <xsl:when test="$buttoncontext='_addaddresses' or $buttoncontext='addaddresses'" >
             <xsl:value-of select="/xslui/@contexturi"/>
             <xsl:text>/help/</xsl:text><xsl:value-of select="$language"/><xsl:text>/addressbk/ncsrchadd.html#wp26183');</xsl:text>
          </xsl:when>
          <xsl:when test="$buttoncontext='_addrecipients'">
             <xsl:value-of select="/xslui/@contexturi"/>
             <xsl:text>/help/</xsl:text><xsl:value-of select="$language"/><xsl:text>/addressbk/mlsrchadd.html#wp26963');</xsl:text>
           </xsl:when>
         <xsl:otherwise>
           <xsl:value-of select="/xslui/@contexturi"/>
           <xsl:text>/help/</xsl:text><xsl:value-of select="$language"/><xsl:text>/addressbk/adrsfpab.html');</xsl:text>
         </xsl:otherwise>
       </xsl:choose>
      </xsl:attribute>
      </input>
      </td>      
     </tr>
     <tr>
       <td colspan="3"><img alt="" src="{$spacer.gif}" width="1" height="6"/></td>
     </tr>
     </tbody>
    </table>
  </xsl:template> 

  <!--
  *****************************************************************************
  * This template prints a legend concerning required info.
  *****************************************************************************
  -->
  <xsl:template name="requiredInfo">
    <table cellspacing="0" cellpadding="0" border="0" bgcolor="#FFFFFF" width="100&#37;" summary="This table contains the legend concerning required info">
      <tr> 
        <td colspan="3">
          <img alt="" src="{$spacer.gif}" width="1" height="3" />
        </td>
      </tr>
      <tr> 
      <td>&nbsp;</td>
      <td>
        <table cellspacing="0" cellpadding="0" border="0">
          <tr>
            <td valign="top">
              <font color="#0000FF" class="bold">*</font>
            </td>
            <td>&nbsp;</td>
            <td>
              <span class="reduced-text">
                <xsl:text>_Indicates required information</xsl:text>
              </span>
            </td>
          </tr>
        </table>
      </td>
      <td>&nbsp;</td>
      </tr>
    </table>
  </xsl:template>

</xsl:stylesheet>
